Imports System.IO

' Open the Add References dialog. On the COM tab, select:
'
'      Microsoft 12.0 Object Library
'
' (Or whatever version you have installed on your system.)

' More examples of automating Excel from C#:
'
'      http:'support.microsoft.com/kb/302084
'      http:'support.microsoft.com/default.aspx?scid=kben-us311452

Imports Excel = Microsoft.Office.Interop.Excel

Public Class Form1
    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        txtFile.Text = Path.GetFullPath( _
            Path.Combine(Application.StartupPath, "..\..")) & _
            "\Items.xlsx"
    End Sub

    ' Read from the Excel workbook.
    Private Sub btnRead_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnRead.Click
        ' Get the Excel application object.
        Dim excel_app As New Excel.ApplicationClass()

        ' Make Excel visible (optional).
        excel_app.Visible = True

        ' Open the workbook read-only.
        Dim workbook As Excel.Workbook = excel_app.Workbooks.Open( _
            Filename:=txtFile.Text, ReadOnly:=True)

        ' Get the first worksheet.
        Dim sheet As Excel.Worksheet = DirectCast(workbook.Sheets(1), Excel.Worksheet)

        ' Get the titles and values.
        SetTitleAndListValues(sheet, 1, 1, lblTitle1, lstItems1)
        SetTitleAndListValues(sheet, 1, 2, lblTitle2, lstItems2)

        ' Save the changes and close the workbook.
        workbook.Close(SaveChanges:=True)

        ' Close the Excel server.
        excel_app.Quit()
    End Sub

    ' Set a title Label and the values in a ListBox. Get the title from cell (row, col).
    ' Get the values from cell (row + 1, col) to the end of the column.
    Private Sub SetTitleAndListValues(ByVal sheet As Excel.Worksheet, _
        ByVal row As Integer, ByVal col As Integer, ByVal lbl As Label, ByVal lst As ListBox)
        Dim range As Excel.Range

        ' Set the title.
        range = DirectCast(sheet.Cells(row, col), Excel.Range)
        lbl.Text = CStr(range.Value2)
        lbl.ForeColor = System.Drawing.ColorTranslator.FromOle( _
            CInt(CDbl(range.Font.Color)))
        lbl.BackColor = System.Drawing.ColorTranslator.FromOle( _
            CInt(CDbl(range.Interior.Color)))

        ' Get the values.
        ' Find the last cell in the column.
        range = DirectCast(sheet.Columns(col, Type.Missing), Excel.Range)
        Dim last_cell As Excel.Range = range.End(Microsoft.Office.Interop.Excel.XlDirection.xlDown)

        ' Get a Range holding the values.
        Dim first_cell As Excel.Range = DirectCast(sheet.Cells(row + 1, col), Excel.Range)
        Dim value_range As Excel.Range = DirectCast(sheet.Range(first_cell, last_cell), Excel.Range)

        ' Get the values.
        Dim range_values As Object(,) = DirectCast(value_range.Value2, Object(,))

        ' Convert this into a 1-dimensional array.
        ' Note that the Range's array has lower bounds 1.
        Dim num_items As Integer = range_values.GetUpperBound(0)
        Dim values1(num_items) As String
        For i As Integer = 0 To num_items - 1
            values1(i) = CStr(range_values(i + 1, 1))
        Next i

        ' Display the values in the ListBox.
        lst.DataSource = values1
    End Sub
End Class
